@@ -41,8 +41,15 @@
 #include <map>
 #include <memory>
 #include <string>
+#include <type_traits>
 
-typedef void *OGRLayerH;
+// Get GDAL's forward decls if available
+// otherwise make our own
+#if __has_include(<gdal_fwd.h>)
+#include <gdal_fwd.h>
+#else
+using OGRLayerH = void *;
+#endif
 
 namespace pdal
 {
@@ -52,13 +59,17 @@ namespace gdal
     class ErrorHandler;
 }
 
+#if __has_include(<gdal_fwd.h>)
+typedef std::shared_ptr<std::remove_pointer<OGRDataSourceH>::type> OGRDSPtr;
+typedef std::shared_ptr<std::remove_pointer<OGRFeatureH>::type> OGRFeaturePtr;
+#else
 typedef std::shared_ptr<void> OGRDSPtr;
 typedef std::shared_ptr<void> OGRFeaturePtr;
-typedef std::shared_ptr<void> OGRGeometryPtr;
+#endif
 
 class Arg;
 
-class PDAL_DLL OverlayFilter : public Filter, public Streamable
+class PDAL_EXPORT OverlayFilter : public Filter, public Streamable
 {
     struct PolyVal
     {
@@ -84,8 +95,6 @@ private:
     OverlayFilter& operator=(const OverlayFilter&) = delete;
     OverlayFilter(const OverlayFilter&) = delete;
 
-    typedef std::shared_ptr<void> OGRDSPtr;
-
     OGRDSPtr m_ds;
     OGRLayerH m_lyr;
     std::string m_dimName;
@@ -96,6 +105,7 @@ private:
     Dimension::Id m_dim;
     std::vector<PolyVal> m_polygons;
     BOX2D m_bounds;
+    int m_threads;
 
 };
 
