@@ -11,7 +11,14 @@ namespace expr
 class BaseParser
 {
 public:
-    BaseParser(Lexer& lexer) : m_lexer(lexer)
+    BaseParser(Lexer& lexer) : m_lexer(lexer), m_endTokens { Token(TokenType::Eof) }
+    {}
+
+    BaseParser(Lexer& lexer, const Token& endToken) : m_lexer(lexer), m_endTokens { endToken }
+    {}
+
+    BaseParser(Lexer& lexer, const std::vector<Token>& endTokens) :
+        m_lexer(lexer), m_endTokens(endTokens)
     {}
 
     bool checkEnd();
@@ -30,6 +37,7 @@ protected:
 
 private:
     Lexer& m_lexer;
+    std::vector<Token> m_endTokens;
     Token m_curTok;
     std::string m_error;
 };
